/////////////////////////////////////////////////////////////////////////////// 
// Copyright (C) 2003-2011, Open Design Alliance (the "Alliance"). 
// All rights reserved. 
// 
// This software and its documentation and related materials are owned by 
// the Alliance. The software may only be incorporated into application 
// programs owned by members of the Alliance, subject to a signed 
// Membership Agreement and Supplemental Software License Agreement with the
// Alliance. The structure and organization of this software are the valuable  
// trade secrets of the Alliance and its suppliers. The software is also 
// protected by copyright law and international treaty provisions. Application  
// programs incorporating this software must include the following statement 
// with their copyright notices:
//   
//   This application incorporates Teigha(R) software pursuant to a license 
//   agreement with Open Design Alliance.
//   Teigha(R) for .dwg files Copyright (C) 2003-2011 by Open Design Alliance. 
//   All rights reserved.
//
// By use of this software, its documentation or related materials, you 
// acknowledge and accept the above terms.
//
//
// *DWG is the native and proprietary file format for AutoCAD(R) and a trademark  
// of Autodesk, Inc.  Open Design Alliance is not associated with Autodesk.
///////////////////////////////////////////////////////////////////////////////



#ifndef _INC_DDBRLOOPVERTEXTRAVERSER_3F82E3080167_INCLUDED
#define _INC_DDBRLOOPVERTEXTRAVERSER_3F82E3080167_INCLUDED

#include "../Br/BrTraverser.h"

class OdBrVertexLoopTraverser;
class OdBrVertex;
class OdBrLoop;
class OdGePoint2d;

#include "../TD_PackPush.h"


/** Description:
    This class is the interface class for loop vertex traversers.

    Library:
    TD_Br

    {group:OdBr_Classes}
*/
class ODBR_TOOLKIT_EXPORT OdBrLoopVertexTraverser : public OdBrTraverser
{
public:
  OdBrLoopVertexTraverser();

  /** Description:
    Returns the *loop* *vertex*.
  */
  OdBrVertex getVertex() const;

 /** Description:
    Returns the owner of the *vertex* list associated with this Traverser object.
  */
  OdBrLoop getLoop() const;

  /** Description:
    Sets this Traverser object to a specific *loop* *vertex* list.
    Arguments:
    loop (I) Owner of the *vertex* list.
    
    Remarks:
    This Traverser object is set to the first element in the list.

    Returns odbrOK if successful, or an appropriate error code if not.
  */
  OdBrErrorStatus setLoop(const OdBrLoop& loop);
  /** Description:
    Sets this Traverser object to a specific *loop* *vertex* list
    and starting position.
    Arguments:
    vertexLoop (I) Defines the loop *vertex* list and starting position.
  */
  OdBrErrorStatus setLoopAndVertex(const OdBrVertexLoopTraverser& vertexLoop);
  
  /** Description:
    Sets the starting position of this Traverser object.
    Arguments:
    vertex (I) Defines the starting position.
  */
  OdBrErrorStatus setVertex(const OdBrVertex& vertex);

  /** Description:
    Returns the parameter space *point* at the current Traverser position.
    Arguments:
    ppoint (O) Parameter *point*.
    
    Remarks:
    Returns odbrOK if successful, or an appropriate error code if not.
  */
  OdBrErrorStatus getParamPoint(OdGePoint2d &point) const;
};

#include "../TD_PackPop.h"

#endif /* _INC_DDBRLOOPVERTEXTRAVERSER_3F82E3080167_INCLUDED */

